@@ -192,6 +192,7 @@ type Config struct {
 	apply           applyCmdConfig
 	archive         archiveCmdConfig
 	chattr          chattrCmdConfig
+	destroy         destroyCmdConfig
 	dump            dumpCmdConfig
 	executeTemplate executeTemplateCmdConfig
 	ignored         ignoredCmdConfig
@@ -201,7 +202,6 @@ type Config struct {
 	mergeAll        mergeAllCmdConfig
 	purge           purgeCmdConfig
 	reAdd           reAddCmdConfig
-	remove          removeCmdConfig
 	secret          secretCmdConfig
 	state           stateCmdConfig
 	unmanaged       unmanagedCmdConfig
@@ -1643,6 +1643,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		c.newCompletionCmd(),
 		c.newDataCmd(),
 		c.newDecryptCommand(),
+		c.newDestroyCmd(),
 		c.newDiffCmd(),
 		c.newDoctorCmd(),
 		c.newDumpCmd(),
@@ -2863,13 +2864,16 @@ func parseCommand(command string, args []string) (string, []string, error) {
 		}); err != nil {
 			return "", nil, err
 		}
-		fields, err := expand.Fields(&expand.Config{
+		switch fields, err := expand.Fields(&expand.Config{
 			Env: expand.FuncEnviron(os.Getenv),
-		}, words...)
-		if err != nil {
+		}, words...); {
+		case err != nil:
 			return "", nil, err
+		case len(fields) > 1:
+			return fields[0], append(fields[1:], args...), nil
+		case len(fields) == 1:
+			return fields[0], args, nil
 		}
-		return fields[0], append(fields[1:], args...), nil
 	}
 
 	// Fallback to the command only.
