@@ -10,6 +10,8 @@ import (
 	"text/template"
 
 	"gopkg.in/yaml.v3"
+
+	"github.com/twpayne/chezmoi/v2/internal/chezmoiset"
 )
 
 var (
@@ -89,30 +91,23 @@ func run() error {
 	delete(supportedPlatforms, newPlatform("windows", "arm64"))
 
 	// Build set of platforms.
-	allPlatforms := make(map[platform]struct{})
+	allPlatforms := chezmoiset.New[platform]()
 	for _, build := range goreleaserConfig.Builds {
-		buildPlatforms := make(map[platform]struct{})
+		buildPlatforms := chezmoiset.New[platform]()
 		for _, goos := range build.GOOS {
 			for _, goarch := range build.GOARCH {
 				platform := newPlatform(goos, goarch)
 				if _, ok := supportedPlatforms[platform]; ok {
-					buildPlatforms[platform] = struct{}{}
+					buildPlatforms.Add(platform)
 				}
 			}
 		}
-		for _, ignore := range build.Ignore {
-			delete(buildPlatforms, ignore)
-		}
-		for platform := range buildPlatforms {
-			allPlatforms[platform] = struct{}{}
-		}
+		buildPlatforms.Remove(build.Ignore...)
+		allPlatforms.AddSet(buildPlatforms)
 	}
 
 	// Sort platforms.
-	sortedPlatforms := make([]platform, 0, len(allPlatforms))
-	for platform := range allPlatforms {
-		sortedPlatforms = append(sortedPlatforms, platform)
-	}
+	sortedPlatforms := allPlatforms.Elements()
 	sort.Slice(sortedPlatforms, func(i, j int) bool {
 		return sortedPlatforms[i].String() < sortedPlatforms[j].String()
 	})
